joblib.parallel\_config
=======================

.. currentmodule:: joblib

.. autoclass:: parallel_config
   :members:

.. _sphx_glr_backreferences_joblib.parallel_config:

.. minigallery:: joblib.parallel_config
    :add-heading: